==> estateplat-common-1.2.4-20210401.082058-693-sources.jar: cn/gtmap/estateplat/model/server/core/GdQlr.java <==
package cn.gtmap.estateplat.model.server.core;

import cn.gtmap.sdk.mybatis.plugin.annotation.Crypt;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * .
 * <p/>
 *
 * @author <a href="mailto:zhaodongdong@gtmap.cn">zdd</a>
 * @version V1.0, 15-4-19
 */
@Table(name = "GD_QLR")
public class GdQlr implements Serializable {
    @Id
    private String qlrid;
    private String qlr;    //权利人
    private String qlrsfzjzl;//权利人身份证件种类
    @Crypt
    private String qlrzjh;//权利人证件号
    private String qlid; //权利ID
    private String qlrlx; //权利人类型（qlr、ywr）
    private String qlrxz; //权利人性质
//    private String sfldsyqr;//是否林地使用权人
//    private String sflmsuqr;//是否林木所有权人
//    private String sflmsyqr;//是否林木使用权人
    private String qlbl; //共有比例
    private String proid; //项目id
    private String sfczr; //是否持证人
    private String cqzh; //产权证号
    private int sxh;//顺序号
    private String qlrdlr; //代理人
    private String qlrdlrzjh; //代理人证件号
    private String qlrdlrzjlx; //代理人证件类型
    //增加冗余字段
    private String qzysxlh;//权证印刷序列号
    private String cqzhjc;//产权证号简称
    private String qlrtxdz;//权利人通讯地址
    private String qlryb;//权利人邮编
    private String gyfs;//共有方式
    private String gyqk;//共有情况
    private String qlrdh;//权利人电话

    public String getQzysxlh() {
        return qzysxlh;
    }

    public void setQzysxlh(String qzysxlh) {
        this.qzysxlh = qzysxlh;
    }

    public String getQlrdlr() {
        return qlrdlr;
    }

    public void setQlrdlr(String qlrdlr) {
        this.qlrdlr = qlrdlr;
    }

    public String getQlrdlrzjh() {
        return qlrdlrzjh;
    }

    public void setQlrdlrzjh(String qlrdlrzjh) {
        this.qlrdlrzjh = qlrdlrzjh;
    }

    public String getQlrdlrzjlx() {
        return qlrdlrzjlx;
    }

    public void setQlrdlrzjlx(String qlrdlrzjlx) {
        this.qlrdlrzjlx = qlrdlrzjlx;
    }

    public String getQlbl() {
        return qlbl;
    }

    public void setQlbl(String qlbl) {
        this.qlbl = qlbl;
    }

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }

    public String getQlr() {
        return qlr;
    }

    public void setQlr(String qlr) {
        this.qlr = qlr;
    }

    public String getQlrsfzjzl() {
        return qlrsfzjzl;
    }

    public void setQlrsfzjzl(String qlrsfzjzl) {
        this.qlrsfzjzl = qlrsfzjzl;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getQlrlx() {
        return qlrlx;
    }

    public void setQlrlx(String qlrlx) {
        this.qlrlx = qlrlx;
    }

    public String getQlrxz() {
        return qlrxz;
    }

    public void setQlrxz(String qlrxz) {
        this.qlrxz = qlrxz;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getSfczr() {
        return sfczr;
    }

    public void setSfczr(String sfczr) {
        this.sfczr = sfczr;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }

    public int getSxh() {
        return sxh;
    }

    public void setSxh(int sxh) {
        this.sxh = sxh;
    }

    public String getCqzhjc() {
        return cqzhjc;
    }

    public void setCqzhjc(String cqzhjc) {
        this.cqzhjc = cqzhjc;
    }

    public String getQlrtxdz() {
        return qlrtxdz;
    }

    public void setQlrtxdz(String qlrtxdz) {
        this.qlrtxdz = qlrtxdz;
    }

    public String getQlryb() {
        return qlryb;
    }

    public void setQlryb(String qlryb) {
        this.qlryb = qlryb;
    }

    public String getGyfs() {
        return gyfs;
    }

    public void setGyfs(String gyfs) {
        this.gyfs = gyfs;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public String getQlrdh() {
        return qlrdh;
    }

    public void setQlrdh(String qlrdh) {
        this.qlrdh = qlrdh;
    }
}

==> estateplat-common-1.2.4-20210926.091805-897-sources.jar: cn/gtmap/estateplat/model/server/core/GdQlr.java <==
package cn.gtmap.estateplat.model.server.core;

import cn.gtmap.sdk.mybatis.plugin.annotation.Crypt;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * .
 * <p/>
 *
 * @author <a href="mailto:zhaodongdong@gtmap.cn">zdd</a>
 * @version V1.0, 15-4-19
 */
@Table(name = "GD_QLR")
public class GdQlr implements Serializable {
    @Id
    private String qlrid;
    private String qlr;    //权利人
    private String qlrsfzjzl;//权利人身份证件种类
    @Crypt
    private String qlrzjh;//权利人证件号
    private String qlid; //权利ID
    private String qlrlx; //权利人类型（qlr、ywr）
    private String qlrxz; //权利人性质
//    private String sfldsyqr;//是否林地使用权人
//    private String sflmsuqr;//是否林木所有权人
//    private String sflmsyqr;//是否林木使用权人
    private String qlbl; //共有比例
    private String proid; //项目id
    private String sfczr; //是否持证人
    private String cqzh; //产权证号
    private int sxh;//顺序号
    private String qlrdlr; //代理人
    private String qlrdlrzjh; //代理人证件号
    private String qlrdlrzjlx; //代理人证件类型
    //增加冗余字段
    private String qzysxlh;//权证印刷序列号
    private String cqzhjc;//产权证号简称
    private String qlrtxdz;//权利人通讯地址
    private String qlryb;//权利人邮编
    private String gyfs;//共有方式
    private String gyqk;//共有情况
    private String qlrdh;//权利人电话

    private String xgzd;//修改字段

    public String getQzysxlh() {
        return qzysxlh;
    }

    public void setQzysxlh(String qzysxlh) {
        this.qzysxlh = qzysxlh;
    }

    public String getQlrdlr() {
        return qlrdlr;
    }

    public void setQlrdlr(String qlrdlr) {
        this.qlrdlr = qlrdlr;
    }

    public String getQlrdlrzjh() {
        return qlrdlrzjh;
    }

    public void setQlrdlrzjh(String qlrdlrzjh) {
        this.qlrdlrzjh = qlrdlrzjh;
    }

    public String getQlrdlrzjlx() {
        return qlrdlrzjlx;
    }

    public void setQlrdlrzjlx(String qlrdlrzjlx) {
        this.qlrdlrzjlx = qlrdlrzjlx;
    }

    public String getQlbl() {
        return qlbl;
    }

    public void setQlbl(String qlbl) {
        this.qlbl = qlbl;
    }

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }

    public String getQlr() {
        return qlr;
    }

    public void setQlr(String qlr) {
        this.qlr = qlr;
    }

    public String getQlrsfzjzl() {
        return qlrsfzjzl;
    }

    public void setQlrsfzjzl(String qlrsfzjzl) {
        this.qlrsfzjzl = qlrsfzjzl;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getQlrlx() {
        return qlrlx;
    }

    public void setQlrlx(String qlrlx) {
        this.qlrlx = qlrlx;
    }

    public String getQlrxz() {
        return qlrxz;
    }

    public void setQlrxz(String qlrxz) {
        this.qlrxz = qlrxz;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getSfczr() {
        return sfczr;
    }

    public void setSfczr(String sfczr) {
        this.sfczr = sfczr;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }

    public int getSxh() {
        return sxh;
    }

    public void setSxh(int sxh) {
        this.sxh = sxh;
    }

    public String getCqzhjc() {
        return cqzhjc;
    }

    public void setCqzhjc(String cqzhjc) {
        this.cqzhjc = cqzhjc;
    }

    public String getQlrtxdz() {
        return qlrtxdz;
    }

    public void setQlrtxdz(String qlrtxdz) {
        this.qlrtxdz = qlrtxdz;
    }

    public String getQlryb() {
        return qlryb;
    }

    public void setQlryb(String qlryb) {
        this.qlryb = qlryb;
    }

    public String getGyfs() {
        return gyfs;
    }

    public void setGyfs(String gyfs) {
        this.gyfs = gyfs;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public String getQlrdh() {
        return qlrdh;
    }

    public void setQlrdh(String qlrdh) {
        this.qlrdh = qlrdh;
    }

    public String getXgzd() {
        return xgzd;
    }

    public void setXgzd(String xgzd) {
        this.xgzd = xgzd;
    }
}
